@@ -1,6 +1,6 @@
 #! Basic necessities to get the CLI running
-from spotdl.search.spotifyClient import initialize
-from sys import argv as cliArgs
+from spotdl.search import spotifyClient
+import sys
 
 #! Song Search from different start points
 from spotdl.search.utils import get_playlist_tracks, get_album_tracks, search_for_song
@@ -9,15 +9,12 @@ from spotdl.search.songObj import SongObj
 #! The actual download stuff
 from spotdl.download.downloader import DownloadManager
 
-#! to avoid packaging errors
-from multiprocessing import freeze_support
-
 
 #! Usage is simple - call 'python __main__.py <links, search terms, tracking files seperated by spaces>
 #! Eg.
 #!      python __main__.py https://open.spotify.com/playlist/37i9dQZF1DWXhcuQw7KIeM?si=xubKHEBESM27RqGkqoXzgQ 'old gods of asgard Control' https://open.spotify.com/album/2YMWspDGtbDgYULXvVQFM6?si=gF5dOQm8QUSo-NdZVsFjAQ https://open.spotify.com/track/08mG3Y1vljYA6bvDt4Wqkj?si=SxezdxmlTx-CaVoucHmrUA
 #!
-#! Well, yeah its a pretty long example but, in theory, it should work like a charm. 
+#! Well, yeah its a pretty long example but, in theory, it should work like a charm.
 #!
 #! A '.spotdlTrackingFile' is automatically  created with the name of the first song in the playlist/album or
 #! the name of the song supplied. We don't really re re re-query YTM and SPotify as all relevant details are
@@ -42,34 +39,33 @@ from multiprocessing import freeze_support
 #! Script Help
 help_notice = '''
 To download a song run,
-    spotdl $trackUrl
-    eg. spotdl https://open.spotify.com/track/08mG3Y1vljYA6bvDt4Wqkj?si=SxezdxmlTx-CaVoucHmrUA
+    spotdl [trackUrl]
+    ex. spotdl https://open.spotify.com/track/0VjIjW4GlUZAMYd2vXMi3b?si=1stnMF5GSdClnIEARnJiiQ
 
 To download a album run,
-    spotdl $albumUrl
-    eg. spotdl https://open.spotify.com/album/2YMWspDGtbDgYULXvVQFM6?si=gF5dOQm8QUSo-NdZVsFjAQ
+    spotdl [albumUrl]
+    ex. spotdl https://open.spotify.com/album/4yP0hdKOZPNshxUOjY0cZj?si=AssgQQrVTJqptFe7X92jNg
 
-To download a playlist run,
-    spotdl $playlistUrl
-    eg. spotdl https://open.spotify.com/playlist/37i9dQZF1DWXhcuQw7KIeM?si=xubKHEBESM27RqGkqoXzgQ
+To download a playlist, run:
+    spotdl [playlistUrl]
+    ex. spotdl https://open.spotify.com/playlist/37i9dQZF1E8UXBoz02kGID?si=oGd5ctlyQ0qblj_bL6WWow
 
-To search for and download a song (not very accurate) run,
-    spotdl $songQuery
-    eg. spotdl 'The HU - Sugaan Essenna'
+To search for and download a song, run, with quotation marks:
+Note: This is not accurate and often causes errors.
+    spotdl [songQuery]
+    ex. spotdl 'The Weeknd - Blinding Lights'
 
-To resume a failed/incomplete download run,
-    spotdl $pathToTrackingFile
-    eg. spotdl 'Sugaan Essenna.spotdlTrackingFile'
+To resume a failed/incomplete download, run:
+    spotdl [pathToTrackingFile]
+    ex. spotdl 'The Weeknd - Blinding Lights.spotdlTrackingFile'
 
-    Note, '.spotDlTrackingFiles' are automatically created during download start, they are deleted on
-    download completion
+    .spotdlTrackingFiles are automatically created when a download starts and deleted on completion
 
-You can chain up download tasks by seperating them with spaces:
-    spotdl $songQuery1 $albumUrl $songQuery2 ... (order does not matter)
-    eg. spotdl 'The Hu - Sugaan Essenna' https://open.spotify.com/playlist/37i9dQZF1DWXhcuQw7KIeM?si=xubKHEBESM27RqGkqoXzgQ ...
+You can queue up multiple download tasks by separating the arguments with spaces:
+    spotdl [songQuery1] [albumUrl] [songQuery2] ... (order does not matter)
+    ex. spotdl 'The Weeknd - Blinding Lights' https://open.spotify.com/playlist/37i9dQZF1E8UXBoz02kGID?si=oGd5ctlyQ0qblj_bL6WWow ...
 
-Spotdl downloads up to 4 songs in parallel - try to download albums and playlists instead of
-tracks for more speed
+spotDL downloads up to 4 songs in parallel, so for a faster experience, download albums and playlist, rather than tracks.
 '''
 
 def console_entry_point():
@@ -78,20 +74,20 @@ def console_entry_point():
     Its super simple, rudimentary even but, it's dead simple & it works.
     '''
 
-    if '--help' in cliArgs or '-h' in cliArgs:
+    if '--help' in sys.argv or '-H' in sys.argv or '-h' in sys.argv or len(sys.argv) == 1:
         print(help_notice)
 
         #! We use 'return None' as a convenient exit/break from the function
         return None
 
-    initialize(
+    spotifyClient.initialize(
         clientId='4fe3fecfe5334023a1472516cc99d805',
         clientSecret='0f02b7c483c04257984695007a4a8d5c'
         )
-    
+
     downloader = DownloadManager()
 
-    for request in cliArgs[1:]:
+    for request in sys.argv[1:]:
         if 'open.spotify.com' in request and 'track' in request:
             print('Fetching Song...')
             song = SongObj.from_url(request)
@@ -102,23 +98,23 @@ def console_entry_point():
                 print('Skipping %s (%s) as no match could be found on youtube' % (
                     song.get_song_name(), request
                 ))
-        
+
         elif 'open.spotify.com' in request and 'album' in request:
             print('Fetching Album...')
             songObjList = get_album_tracks(request)
 
             downloader.download_multiple_songs(songObjList)
-        
+
         elif 'open.spotify.com' in request and 'playlist' in request:
             print('Fetching Playlist...')
             songObjList = get_playlist_tracks(request)
 
             downloader.download_multiple_songs(songObjList)
-        
+
         elif request.endswith('.spotdlTrackingFile'):
             print('Preparing to resume download...')
             downloader.resume_download_from_tracking_file(request)
-        
+
         else:
             print('Searching for song "%s"...' % request)
             try:
@@ -127,10 +123,8 @@ def console_entry_point():
 
             except Exception:
                 print('No song named "%s" could be found on spotify' % request)
-    
+
     downloader.close()
 
 if __name__ == '__main__':
-    freeze_support()
-
-    console_entry_point()
\ No newline at end of file
+    console_entry_point()
